clear all
close all

% Matlab script to generate STIPA signals with carriers at the edges of 
% the generation bands (1/2 octave wide around each 1/1 octave). 
% These signals are used to test the influence of the analysis filter bands phase response. 
% The phase response of the analysis filter should not yield a systematic error 
% higher than 0,01 STI for the (S)TI range [0,1 - 0,9] (equal to the SNR range [-12 +12]).
% For optimal resolution, the measurements are performed with auditory masking disabled 
% Subsequently, the levels per band has been set to 0 dB.   
%
% These test signals can be used for algorithm testing, (see section A.3.1.2)
% www.stipa.info

STIrevision = 5;

Author  =   'Jan Verhave';
Version =   '1.0';
Date    =   '3 June 2020';
Copyright = 'Embedded Acoustics BV, the Netherlands';

fs      =   48000;  % samplerate
T       =   30;     % set to 100 seconds to obtain a seamless test signal

OCTAVES =   [ 125  250  500  1000 2000 4000 8000];
FMODLO  =   [ 1.6  1.0  0.63  2.0 1.25  0.8  2.5];
FMODHI  =   5*FMODLO;

s       =   [1:fs*T];
t       =   (s-1)/fs;
m       =   1.0;

TI      =   [0.0:0.1:1.0];
SNR     =   TI*30-15;
E       =   10.^(SNR/10);
m       =   E./(1+E);

% clip the lowest and the highest m-value to zero and one
m(1)    =   0;
m(end)  =   1;

for i=1:length(TI)
    y       =   0;
    for j=1:length(OCTAVES)
        G   =   1;
        c   =   2^(1/4);  % set carriers at the edges of the generation bands (1/2 octave wide)
        CAR1=   sin(2*pi*OCTAVES(j)/c*t);
        CAR2=   sin(2*pi*OCTAVES(j)*c*t);
        MOD =   sqrt(0.5*(1+0.55*m(i)*(sin(2*pi*FMODLO(j)*t)-sin(2*pi*FMODHI(j)*t))));    
        y   =   y+G*MOD.*(CAR1+CAR2);
    end
    y   =   y/max(abs(y));
    wavwrite(y,fs,['STIPA-sine-edge-carriers-TI=' num2str(TI(i)) '[m=' num2str(m(i)) '].wav']);
end









